@@ -39,17 +39,20 @@ from antlr4.tree.Tree import ParseTreeListener
 
 class TraceListener(ParseTreeListener):
     
-    def enterEveryRule(self, parser, ctx):
-        print("enter   " + parser.ruleNames[ctx.ruleIndex] + ", LT(1)=" + parser._input.LT(1).text)
+    def __init__(self, parser):
+        self._parser = parser
 
-    def visitTerminal(self, parser, node):
-        print("consume " + node.symbol + " rule " + parser.ruleNames[parser._ctx.ruleIndex])
+    def enterEveryRule(self, ctx):
+        print("enter   " + self._parser.ruleNames[ctx.getRuleIndex()] + ", LT(1)=" + self._parser._input.LT(1).text)
 
-    def visitErrorNode(self, parser, node):
+    def visitTerminal(self, node):
+        print("consume " + str(node.symbol) + " rule " + self._parser.ruleNames[self._parser._ctx.getRuleIndex()])
+
+    def visitErrorNode(self, node):
         pass
 
-    def exitEveryRule(self, parser, ctx):
-        print("exit    " + parser.ruleNames[ctx.ruleIndex] + ", LT(1)=" + parser._input.LT(1).text)
+    def exitEveryRule(self, ctx):
+        print("exit    " + self._parser.ruleNames[ctx.getRuleIndex()] + ", LT(1)=" + self._parser._input.LT(1).text)
 
 
 # self is all the parsing support code essentially; most of it is error recovery stuff.#
@@ -157,7 +160,7 @@ class Parser (Recognizer):
             self.consume()
         else:
             t = self._errHandler.recoverInline(self)
-            if self._buildParseTrees and t.tokenIndex == -1:
+            if self.buildParseTrees and t.tokenIndex == -1:
                 # we must have conjured up a new token during single token insertion
                 # if it's not the current symbol
                 self._ctx.addErrorNode(t)
@@ -568,5 +571,5 @@ class Parser (Recognizer):
         else:
             if self._tracer is not None:
                 self.removeParseListener(self._tracer)
-            self._tracer = TraceListener()
+            self._tracer = TraceListener(self)
             self.addParseListener(self._tracer)
